@@ -74,17 +74,22 @@ setMethod("solve", signature(a = "dtCMatrix", b = "missing"),
 
 setMethod("solve", signature(a = "dtCMatrix", b = "dgeMatrix"),
 	  function(a, b, ...) {
-	      if (a@diag == "U") a <- as(diagU2N(a), "dtCMatrix")
+#	      if (a@diag == "U") a <- as(diagU2N(a), "dtCMatrix")
+              if (a@diag == "U") a <- .Call(Csparse_diagU2N, a)
 	      .Call(dtCMatrix_matrix_solve, a, b, TRUE)
 	  }, valueClass = "dgeMatrix")
 
 setMethod("solve", signature(a = "dtCMatrix", b = "matrix"),
 	  function(a, b, ...) {
-	      if (a@diag == "U") a <- as(diagU2N(a), "dtCMatrix")
+#	      if (a@diag == "U") a <- as(diagU2N(a), "dtCMatrix")
+              if (a@diag == "U") a <- .Call(Csparse_diagU2N, a)
 	      storage.mode(b) <- "double"
 	      .Call(dtCMatrix_matrix_solve, a, b, FALSE)
 	  }, valueClass = "dgeMatrix")
 
+## Isn't this case handled by the method for (a = "Matrix', b =
+## "numeric") in ./Matrix.R? Or is this method defined here for
+## the as.double coercion?
 setMethod("solve", signature(a = "dtCMatrix", b = "numeric"),
 	  function(a, b, ...) {
 	      if (a@diag == "U") a <- as(diagU2N(a), "dtCMatrix")
