@@ -2,28 +2,30 @@
 
 ### contains = "lsparseMatrix"
 
-setMethod("%*%", signature(x = "lgCMatrix", y = "lgCMatrix"),
-          function(x, y)
-          .Call(lgCMatrix_lgCMatrix_mm, x, y),
-          valueClass = "lgCMatrix")
+## Can use CsparseMatrix methods for all of these
 
-setMethod("t", signature(x = "lgCMatrix"),
-          function(x) .Call(lgCMatrix_trans, x),
-          valueClass = "lgCMatrix")
+## setMethod("%*%", signature(x = "lgCMatrix", y = "lgCMatrix"),
+##           function(x, y)
+##           .Call(lgCMatrix_lgCMatrix_mm, x, y),
+##           valueClass = "lgCMatrix")
 
-setMethod("crossprod", signature(x = "lgCMatrix", y = "missing"),
-	  function(x, y = NULL)
-          .Call(lgCMatrix_crossprod, x, TRUE, NULL),
-	  valueClass = "lsCMatrix")
+## setMethod("t", signature(x = "lgCMatrix"),
+##           function(x) .Call(lgCMatrix_trans, x),
+##           valueClass = "lgCMatrix")
 
-setMethod("tcrossprod", signature(x = "lgCMatrix", y = "missing"),
-	  function(x, y = NULL)
-          .Call(lgCMatrix_crossprod, x, FALSE, NULL),
-	  valueClass = "lsCMatrix")
 
-setMethod("diag", signature(x = "lgCMatrix"),
-	  function(x, nrow, ncol = n) .Call(lgCMatrix_diag, x))
+## setMethod("diag", signature(x = "lgCMatrix"),
+## 	  function(x, nrow, ncol = n) .Call(lgCMatrix_diag, x))
 
+## setMethod("crossprod", signature(x = "lgCMatrix", y = "missing"),
+## 	  function(x, y = NULL)
+##           .Call(lgCMatrix_crossprod, x, TRUE, NULL),
+## 	  valueClass = "lsCMatrix")
+
+## setMethod("tcrossprod", signature(x = "lgCMatrix", y = "missing"),
+## 	  function(x, y = NULL)
+##           .Call(lgCMatrix_crossprod, x, FALSE, NULL),
+## 	  valueClass = "lsCMatrix")
 
 setAs("lgCMatrix", "dgCMatrix",
       function(from) new("dgCMatrix", i = from@i, p = from@p,
